VirtualListProps

Struct VirtualListProps 

pub struct VirtualListProps {
    pub items: ItemGenerator,
    pub item_count: usize,
    pub height_prior: ItemSize,
    pub classes: Classes,
    pub item_classes: Classes,
}
Properties for a VirtualList.

Fields

items: ItemGenerator

A callback to render individual items. Only invoked for items on screen. Use VirtualList::item_gen to create an ItemGenerator.

item_count: usize

The number of items in the list, in total. Items that are not visible on screen take up scroll space and are lazily instantiated when the user scrolls to them later.

height_prior: ItemSize

An approximate height for items that haven’t been rendered, yet, but should still take up scroll space. After the first render of an item, the height will be adjusted automatically and measured.

Setting this to an inaccurate value will mis-represent the remaining scroll distance, but cause no other ill effects.

classes: Classes

Additional classes to apply to the scroll list itself.

Gotcha

The list itself is rendered without a max height or other layout constraints to stay independent of a particular css solution. Use these additional classes to apply additional css to the list.

item_classes: Classes

Individual items are wrapped in a <div> to take their measurements in a block context. The classes here are applied to each such wrapper. Usually, you don’t need to supply this property.